# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['errornumbers']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'errornumbers',
    'version': '0.10.1',
    'description': 'Classes and functions for handling with numbers with errors',
    'long_description': '# Error Numbers library for python  \n  \n## Installatie  \n  \n- Installatie via [pip](https://phoenixnap.com/kb/install-pip-windows) (eenvoudigste manier)  \n  - Open een terminal. (Kan via Pycharm (Alt + F12) of manueel via de zoekbalk in windows).  \n  - gebruik het command `pip install errornumbers`.  \n- Manuele installatie  \n  - Download [errornumbers.py](https://github.com/aap007freak/errornumbers/blob/master/errornumbers.py) van deze github repository.  \n  - Zet ze in dezelfde map als je python scripts; je kan de bestanden nu gebruiken.  \n  \n  \n## Gebruik  \n  \nVanboven in elke python file waarin je deze package wilt gebruiken, moet je volgende lijn zetten:  \n  \n```python  \nfrom errornumbers import ErrorNumber  \n```  \n  \nHeel de library draait rond het object *ErrorNumber*. Je kan deze aanmaken op deze manier:  \n  \n  \n```python  \n#ErrorNumber met absolute fout  \nmy_error_number = ErrorNumber(waarde, absolute_fout)  \n#ErrorNumber met relatieve fout  \nmy_error_number = ErrorNumber(waarde, relatieve_fout, relative=True)  \n```  \n  \n  \nEen ErrorNumber object heeft drie variabelen; value, absolute_error en relative_error. De waarde en fout van een ErrorNumber zijn steeds reëel.  \n Je kan ze op onderstaande manier opvragen.  \n  \n```python  \n#Maak een ErrorNumber  \nmy_error_number = ErrorNumber(5, 0.1)  \n  \nprint(my_error_number.value)  \n#prints 5  \nprint(my_error_number.absolute_error)  \n#prints 0.1  \nprint(my_error_number.relative_error)  \n#prints 0.02  \n  \n#Wanneer je het hele object print:  \nprint(my_error_number)  \n#prints [value=5; error=0.1; relative_error=0.02]  \n  \n```  \n  \n  \nErrorNumbers zijn **immutable**. Dit betekent dat je de waarde van een ErrorNumber niet kan veranderen. Wanneer je aan de hand van een functie een ErrorNumber bewerkt, geeft die functie een nieuwe ErrorNumber terug en wordt de originele ErrorNumber behouden.  \n  \n```python  \n#Maak een ErrorNumber  \noriginal_error_number = ErrorNumber(5, 0.1)  \n#plus 5  \nnew_error_number = original_error_number + 5  \n  \nprint(original_error_number)  \n#prints [value=5; error=0.1; relative_error=0.02]  \nprint(new_error_number)  \n#prints [value=10; error=0.1; relative_error=0.02]  \n```  \nAls je een bestaande operatie (zoals +, -, ... ) op twee ErrorNumbers uitvoert, dan worden de fouten automatisch meegepropageerd.   \nAls er een ander type wordt doorgegeven, dan wordt de variabele als een constante beschouwd (zonder fout dus).    \n  \nFunctie | Afkorting | Beschrijving  \n--- | --- | ---  \n`.plus(other_errornumber)` | + | telt een ErrorNumber bij een andere ErrorNumber op.    \n`.plusc(constant)` | + | telt bij een Errornumber een constante op  \n`.minus(other_errornumber)` | - | trekt een ErrorNumber van een andere ErrorNumber af  \n`.minusc(constant)` | - | trekt een constante van een ErrorNumber af  \n`.times(other_errornumber)` | * | vermenigvuldigt een ErrorNumber met een andere ErrorNumber  \n`.timesc(constant)` | * | vermenigvuldigt een ErrorNumber met een constante  \n`.divided_by(other_errornumber)` | / | deelt een ErrorNumber door een andere ErrorNumber  \n`.divided_byc(constant)` | / | deelt een ErrorNumber door een constante  \n`.inverse()` |  | inverteert een ErrorNumber  \n`.squared()` |  | geeft het kwadraat van een ErrorNumber  \n`.cubed()` |  | geeft de derde macht van een ErrorNumber  \n`.to_the(constant)` | ** | geeft de n-de macht van een ErrorNumber  \n  \n  \nGoniometrische en andere bewerkingen kunnen ook gebruikt wordt, mits ze eerst geïmporteerd worden  \n  \n```python  \nfrom errornumbers import sin, exp  \n```  \n  \nEen lijstje met functies die geïmporteerd moeten worden voor gebruik staan hieronder.  \nFunctie | Beschrijving  \n--- | ---  \n`sin(errornumber)` |neemt de sinus van een ErrorNumber*.  \n`cos(errornumber)` | neemt de cosinus van een ErrorNumber*  \n`tan(errornumber)` | neemt de tangens van een ErrorNumber*  \n`cot(errornumber)` | neemt de cotangens van een ErrorNumber*  \n`exp(errornumber)` | verheft e tot errornumber  \n`expbase(errornumber, base)` | verheft een base tot het errornumber  \n`from_non_reproducible(list)` | berekent een waarde met fout = 3 * SF uit niet-reproduceerbare metingen.\n  \n*** *goniometrische formules verwachten steeds een argument in radialen*  \n  \nHet is niet bijster moeilijk om zelf custom functies van ErrorNumbers te schrijven met custom foutenpropagatie.\n## Over het import statement  \n  \nPython laat het toe om import statements een andere naam te geven, dit om je code te verkorten.  \n  \nBijvoorbeeld:  \n  \n```python  \nfrom errornumbers import ErrorNumber as EN  \n  \nmy_error_number = EN(5, 0.1)  \n  \nfrom errornumbers import sin as s  \n  \nprint( s(my_error_number) )  \n```  \n  \nOok kan je heel de package in 1 keer importen met het commando `from errornumbers import *`.  \nDan kan je alle functies en het ErrorNumber object direct in je scripts gebruiken  \n  \n```python  \nfrom errornumbers import *  \n  \nmy_error_number = ErrorNumber(0.1, 0.1, relative=True)  \n```  \n  \n## Voorbeeld  \n  \n### brekingsindex van een prisma  \n  \nWe kunnen aan de hand van de tophoek ![\\alpha](https://latex.codecogs.com/svg.latex?\\space\\alpha) en de deviatiehoek ![\\delta](https://latex.codecogs.com/svg.latex?d) van een prisma de brekingsindex bepalen met de formule  \n  \n![\\frac{\\sin{\\frac{\\alpha + d}{2}}}{\\sin{\\frac{\\alpha}{2}}}](https://latex.codecogs.com/svg.latex?\\Large&space;n=\\frac{\\sin{\\frac{\\alpha+d}{2}}}{\\sin{\\frac{\\alpha}{2}}})  \n  \n```Python  \nfrom errornumbers import ErrorNumber as EN  \nfrom errornumbers import sin  \nimport math  \n  \n#in degrees  \nalpha = EN(60, 0.5)  \ndelta = EN(40, 1.2)  \n  \nradian_alpha = alpha * math.pi / 180  \nradian_delta = delta * math.pi / 180  \n  \n  \nnumerator = sin( (radian_alpha + radian_delta) / 2)  \ndenominator = sin(radian_alpha/ 2)  \n  \nn = numerator / denominator  \n  \nn_degrees = n * 180 / math.pi  \nprint(n)  \n  \n```  \n  \n  \n## Contributing / Opmerkingen  \n- English version will follow soon  \n- Not every method has been tested',
    'author': 'Anton Leagre',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aap007freak/errornumbers',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
